package main

import (
	"log"
	"time"
)

func main() {
	// Load configuration
	config, err := loadConfig("config.json")
	if err != nil {
		log.Fatalf("Failed to load configuration: %v", err)
	}

	// Create database
	db, err := NewSQLiteDb("tags.db")
	if err != nil {
		log.Fatalf("Failed to create database: %v", err)
	}

	notifier := NtfyNotifier{Topic: config.NtfyTopic}

	// Main loop
	for {
		for _, repo := range config.Repos {
			tag, err := repo.GetLatestTag()
			if err != nil {
				log.Printf("Failed to get latest tag for %s: %v", repo.Repo, err)
				continue
			}
			if tag.Name == "" {
				log.Printf("No tags found for %s", repo.Repo)
				continue
			}

			// Check and store tag
			stored, err := db.CheckAndStore(repo.Repo, tag.Name)
			if err != nil {
				log.Printf("Failed to store tag for %s: %v", repo.Repo, err)
				continue
			}
			if stored {
				log.Printf("New tag stored for %s: %s", repo.Repo, tag.Name)
				if notifier.Notify(repo, tag.Name) {
					log.Printf("Notified for %s/%s: %s", repo.Owner, repo.Repo, tag.Name)
				}
			}
		}
		time.Sleep(time.Duration(config.Interval) * time.Second)
	}
}
